@@ -34,6 +34,8 @@ jQuery(function($){
     }
   };
 
+  var authenticator_token = $('.dashboardContent').data('authenticator-token');
+
   var update_dashboard_order = function(event, ui) {
     // the update event handler is called twice (once with ui.sender
     // and once without). ui.sender needs to be Null, otherwise
@@ -76,7 +78,7 @@ jQuery(function($){
 
           // edit link must be fixed: the column id may be wrong!
           // test if there is a edit link
-          var editLinks = $('#portletwrapper-' + newHash + ' .edit');
+          var editLinks = $('#portletwrapper-' + newHash + ' .buttonEdit');
           if(editLinks.length>0) {
             var editLink = editLinks[0];
             var href = editLink.getAttribute("href").replace(oldHash, newHash);
@@ -90,12 +92,18 @@ jQuery(function($){
       type :      'POST',
       url :       './ftw.dashboard.dragndrop-update_order',
       data :      customSerialization(),
+      beforeSend: function (request){
+        request.setRequestHeader("X-CSRF-TOKEN", authenticator_token);
+      },
       success :   function(msg) {
         updateHashesCallback(msg);
         // we need to send the changes with updated hashes again
         $.ajax({
           type :      'POST',
           url :       './ftw.dashboard.dragndrop-update_order',
+          beforeSend: function (request){
+            request.setRequestHeader("X-CSRF-TOKEN", authenticator_token);
+          },
           data :      customSerialization()
         });
       }
@@ -114,8 +122,6 @@ jQuery(function($){
     update :        update_dashboard_order
   });
 
-  $('.column').disableSelection();
-
   /* TOGGLE PORTLET CONTENT */
   $('.portletHeader a.buttonOpen, .portletHeader a.buttonClose').live('click',function(e) {
     e.preventDefault();
@@ -132,6 +138,9 @@ jQuery(function($){
     }
     $.ajax({
       type :      'POST',
+      beforeSend: function (request){
+        request.setRequestHeader("X-CSRF-TOKEN", authenticator_token);
+      },
       url :       './ftw.dashboard.dragndrop-foldportlet',
       data :      'hash='.concat(hash)+'&folded='.concat(folded)
     });
@@ -164,15 +173,10 @@ jQuery(function($){
     e.preventDefault();
     var wrapper = $(this).parents('.portletwrapper:first');
     var hash = wrapper.attr('id').substr('portletwrapper-'.length);
-    var pos = ($('#visual-portal-wrappers').width() / 2) - 150;
-    // fallback if there is no element visual-portal-wrapper
-    if ($('#visual-portal-wrappers').length === 0) {
-      pos = ($('body').width() / 2) - 150;
-    }
     $('<div></div>').
       html('<div id="remove-portlet-dialog">'+$('#text-remove-portlet').html()+'</div>').
       dialog({
-        modal: true, resizable: false, position:[pos, 100],
+        modal: true, resizable: false, position: {my: "center", at: "top+200"}, width: 1200,
         buttons: [
           {
             text: $("#text-remove-portlet-yes").html(),
@@ -180,6 +184,9 @@ jQuery(function($){
               $.ajax({
                 type : 'POST',
                 url : './ftw.dashboard.dragndrop-removeportlet',
+                beforeSend: function (request){
+                  request.setRequestHeader("X-CSRF-TOKEN", authenticator_token);
+                },
                 data : 'hash='.concat(hash)
               });
               // destroy it
